Geometry (Geo)
--------------
A geometry function module.

**Point Functions:**

* ptOffset
* ptNeg
* ptProduct
* ptProductScalar
* ptProductVector
* ptDistance
* ptInBoxp
* ptNearestBoxSide
* ptSnapToGrid

**bBox Functions:**

* bBoxOffset
* bBoxSnapToGrid
* bBoxFromSize
* bBoxSize

**Other Functions:**

* figFlattenOverlaps
* mosFlatten


.. dropdown:: Geo.ils sourcecode

    .. literalinclude:: ../../_static/src/Geo.ils
       :language: scheme
       :linenos:
